pub enum TooFewItemsOrOom {
TooFewItems(TooFewItems),
Oom(OutOfMemory),
}Expand description
An error returned by new_boxed_slice_from_iter.
Variants
TooFewItems(TooFewItems)
The iterator did not yield enough items to fill the boxed slice.
Oom(OutOfMemory)
Failed to allocate space for the boxed slice.
Implementations
Sourceimpl TooFewItemsOrOom
impl TooFewItemsOrOom
Sourcepub fn unwrap_oom(&self) -> OutOfMemory
pub fn unwrap_oom(&self) -> OutOfMemory
Unwrap the inner OutOfMemory error, or panic if this is a different
error variant.