Module array

Module array 

Not yet stable array functions needed by fixed length list

Functions

array_try_from_fn
Creates an array [T; N] where each fallible array element T is returned by the cb call. Unlike core::array::from_fn, where the element creation can’t fail, this version will return an error if any element creation was unsuccessful.