OutOfMemory

Struct OutOfMemory 

pub struct OutOfMemory { /* private fields */ }
Out-of-memory error.

This error is the sentinel for allocation failure due to memory exhaustion.

Constructing an Error from an OutOfMemory does not allocate.

Allocation failure inside any Error method that must allocate (e.g. Error::context) will propagate an OutOfMemory error.

Implementations

Source

impl OutOfMemory

pub const fn new(requested_allocation_size: usize) -> Self

Construct a new OutOfMemory error.

The requested_allocation_size argument should be the size (in bytes) of the associated allocation that was attempted and failed.

This operation does not allocate.

Example
use alloc::alloc::{Layout, alloc};
use core::ptr::NonNull;

/// Attempt to allocate a block of memory from the global allocator,
/// returning an `OutOfMemory` error on failure.
fn try_global_alloc(layout: Layout) -> Result<NonNull<u8>, OutOfMemory> {
    if layout.size() == 0 {
        return Ok(NonNull::dangling());
    }

    // Safety: the layout's size is non-zero.
    let ptr = unsafe { alloc(layout) };

    if let Some(ptr) = NonNull::new(ptr) {
        Ok(ptr)
    } else {
        // The allocation failed, so return an `OutOfMemory` error,
        // passing the attempted allocation's size into the `OutOfMemory`
        // constructor.
        Err(OutOfMemory::new(layout.size()))
    }
}
pub fn requested_allocation_size(&self) -> usize

Get the size (in bytes) of the associated allocation that was attempted and which failed.

Very large allocation sizes (near isize::MAX and larger) may be capped to a maximum value.

Example
let oom = OutOfMemory::new(8192);
assert_eq!(oom.requested_allocation_size(), 8192);