Module undo
wasmtime_
internal_
core
44.0.0
Module undo
Module Items
Structs
In crate wasmtime_
internal_
core
wasmtime_internal_core
Module
undo
Helpers for undoing partial side effects when their larger operation fails.
Structs

Undo
An RAII guard to rollback and undo something on (early) drop.