Not yet stable array functions needed by fixed length list
Functions
- array_
try_ from_ fn - Creates an array
[T; N]where each fallible array elementTis returned by thecbcall. Unlikecore::array::from_fn, where the element creation can’t fail, this version will return an error if any element creation was unsuccessful.